# cs207-FinalProject
[![Build Status](https://travis-ci.org/veritorch/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/veritorch/cs207-FinalProject)
[![codecov](https://codecov.io/gh/veritorch/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/veritorch/cs207-FinalProject)

Final Project Code

Group Number: 9

Names:
- Yixing Guan
- Yinan Shen
- Shuying Ni
- Banruo (Rock) Zhou
